@@ -1,5 +1,6 @@
 from enum import Enum
 from pathlib import Path
+from typing import List,Dict
 from .util import get_indent, from_first_letter
 
 
@@ -23,7 +24,7 @@ class EnvType(Enum):
     NONE = 4
 
 
-def __env_dict_from_lines(__env_lines: list[str]):
+def __env_dict_from_lines(__env_lines: List[str]):
     env_lines = __env_lines.copy()
     env_lines.sort()
     env_kv_pairs = [line.split("=", 1) for line in env_lines if "=" in line]
@@ -94,13 +95,13 @@ def env_dict(path: str = None, src: str = None, env: EnvType = EnvType.NONE):
     return result
 
 
-def form_dotenv_src(__dict: dict[str, str]):
+def form_dotenv_src(__dict: Dict[str, str]):
     env_lines = [f"{key}={value}" for key, value in __dict.items()]
     env_lines.sort()
     return "\n".join(env_lines) if env_lines else ""
 
 
-def form_python_env_src(env: dict[str, str], dotenv_path: str = ".env",python_path:str="env.py"):
+def form_python_env_src(env: Dict[str, str], dotenv_path: str = ".env",python_path:str="env.py"):
 
     field_src = lambda key: f"    {key}:Optional[str] = Field(default=None)"
     keys = list(env.keys())
@@ -137,7 +138,7 @@ class Env(BaseModel):
 
 
 def form_dockerfile_env_src(
-    __dict: dict[str, str], dockerfile_path: str = "Dockerfile"
+    __dict: Dict[str, str], dockerfile_path: str = "Dockerfile"
 ):
     dockerfile_lines = []
     if path_exists(dockerfile_path):
